@@ -8,7 +8,7 @@
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '1.0-1'
+Version = '1.1-3'
 
 import os
 import sys
@@ -32,17 +32,26 @@ ConfigMain    = 'tuning'                       # tuning file
 
 ##############################################################
 
-def CheckFile(Path, File):       
+def checkFile(Path, File):       
     ''' Check if a file exists. '''
 
     try:
         f = open(Path + "/" + File, 'r')
         f.close()
+        return True
     except:
         return False
-    else:
-        return True
 
+def checkMMC1():
+    ''' Check if mmc1 installed. '''
+    
+    try:
+        f = open('/sys/block/mmcblk1/queue/nr_requests', 'r')
+        f.close()
+        return True
+    except:
+        return False
+        
 def showMessage(message):        
     ''' Method to display a message to the user that waits for an action. '''
 
@@ -157,7 +166,7 @@ class MyMainWindow(QtGui.QMainWindow):
         
              ##Build parent user interface
              QtGui.QWidget.__init__(self, parent)
-             self.ui = Ui_swappolube()
+             self.ui = Ui_Swappolube()
              self.ui.setupUi(self)
              ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
              self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
@@ -190,7 +199,7 @@ class MyMainWindow(QtGui.QMainWindow):
         def doDeleteTunings(self):
         
              os.system('sudo %s/updateTuning deleteTuning' % PathApp)
-             if CheckFile(PathSystem, ConfigMain) == True:
+             if checkFile(PathSystem, ConfigMain) == True:
                 message = 'The tuning file could not be deleted.\
                            \nPlease delete it manually.'
              else: 
@@ -216,8 +225,13 @@ class MyMainWindow(QtGui.QMainWindow):
              os.system('sudo %s/updateTuning Swappiness 100' % PathApp )
              os.system('sudo %s/updateTuning DirtyBGDRatio 10' % PathApp )
              os.system('sudo %s/updateTuning VFSCachePressure 100' % PathApp )
+             #new options in ver. 1.1-1
+             os.system('sudo %s/updateTuning mmc0requests 128' % PathApp )
+             if checkMMC1() == True:
+                os.system('sudo %s/updateTuning mmc1requests 128' % PathApp )
+             os.system('sudo %s/updateTuning minFreekbytes 2039' % PathApp )
              
-             if CheckFile(PathSystem, ConfigMain) == True:
+             if checkFile(PathSystem, ConfigMain) == True:
                 message = 'The default values have been restored to the system.\n\nWARNING: A tuning file exists and will reapply its settings on the next reboot.'
              else:   
                 message = 'The default values have been restored to the system.'
@@ -246,6 +260,10 @@ class MyMainWindow(QtGui.QMainWindow):
              radioTCPTimestamps           = '0'
              radioTCPNoMetricsSave        = '0'
 
+             radiommc0requests            = '0'
+             radiommc1requests            = '0'
+             radioMinFreekbytes           = '0'
+
              if self.ui.radioSwappiness.isChecked() == True:
                 radioSwappiness              = '1'
              if self.ui.radioDirtyRatio.isChecked() == True:
@@ -269,6 +287,12 @@ class MyMainWindow(QtGui.QMainWindow):
              if self.ui.radioTCPNoMetricsSave.isChecked() == True:
                 radioTCPNoMetricsSave        = '1'
 
+             if self.ui.radiommc0requests.isChecked() == True:
+                radiommc0requests        = '1'
+             if self.ui.radiommc1requests.isChecked() == True:
+                radiommc1requests        = '1'
+             if self.ui.radioMinFreekbytes.isChecked() == True:
+                radioMinFreekbytes        = '1'
              
              Swappiness                   = self.ui.lineSwappiness.text()
              DirtyRatio                   = self.ui.lineDirtyRatio.text()
@@ -279,6 +303,10 @@ class MyMainWindow(QtGui.QMainWindow):
              VFSCachePressure             = self.ui.lineVFSCachePressure.text()
              LaptopMode                   = self.ui.lineLaptopMode.text()
              
+             mmc0requests                 = self.ui.linemmc0requests.text()
+             #if checkMMC1() == True:
+             mmc1requests                 = self.ui.linemmc1requests.text()
+             minFreekbytes                = self.ui.lineMinFreekbytes.text()
              
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
                 KillAllocatingTask = '1'
@@ -294,8 +322,9 @@ class MyMainWindow(QtGui.QMainWindow):
                 TCPNoMetricsSave = '0'   
                 
              ##Write values to the custom file.
-
-             os.system('echo "radioSwappiness = %s\
+             
+             try:
+                os.system('echo "radioSwappiness = %s\
                              \nSwappiness = %s\
                              \nradioDirtyRatio = %s\
                              \nDirtyRatio = %s\
@@ -316,22 +345,34 @@ class MyMainWindow(QtGui.QMainWindow):
                              \nradioTCPTimestamps = %s\
                              \nTCPTimestamps = %s\
                              \nradioTCPNoMetricsSave = %s\
-                             \nTCPNoMetricsSave = %s" > %s/%s' % (  radioSwappiness, Swappiness, 
-                                                                    radioDirtyRatio,DirtyRatio,
-                                                                    radioDirtyBGDRatio, DirtyBGDRatio,
-                                                                    radioDirtyExpireCentisecs, DirtyExpireCentisecs,
-                                                                    radioDirtyWritebackCentisecs, DirtyWritebackCentisecs,
-                                                                    radioPageCluster, PageCluster,
-                                                                    radioVFSCachePressure, VFSCachePressure,
-                                                                    radioLaptopMode, LaptopMode,
-                                                                    radioKillAllocatingTask, KillAllocatingTask,
-                                                                    radioTCPTimestamps, TCPTimestamps,
-                                                                    radioTCPNoMetricsSave, TCPNoMetricsSave, 
-                                                                    PathApp, ConfigCustom ) )
+                             \nTCPNoMetricsSave = %s\
+                             \nradiommc0requests = %s\
+                             \nmmc0requests = %s\
+                             \nradiommc1requests = %s\
+                             \nmmc1requests = %s\
+                             \nradioMinFreekbytes = %s\
+                             \nminFreekbytes = %s" > %s/%s' % ( radioSwappiness, Swappiness, 
+                                                                radioDirtyRatio,DirtyRatio,
+                                                                radioDirtyBGDRatio, DirtyBGDRatio,
+                                                                radioDirtyExpireCentisecs, DirtyExpireCentisecs,
+                                                                radioDirtyWritebackCentisecs, DirtyWritebackCentisecs,
+                                                                radioPageCluster, PageCluster,
+                                                                radioVFSCachePressure, VFSCachePressure,
+                                                                radioLaptopMode, LaptopMode,
+                                                                radioKillAllocatingTask, KillAllocatingTask,
+                                                                radioTCPTimestamps, TCPTimestamps,
+                                                                radioTCPNoMetricsSave, TCPNoMetricsSave, 
+                                                                radiommc0requests, mmc0requests,
+                                                                radiommc1requests, mmc1requests, 
+                                                                radioMinFreekbytes, minFreekbytes,
+                                                                PathApp, ConfigCustom ) )
 
-             message = 'The custom settings have been saved.'
-             showMessage(message)             
-             
+                message = 'The custom settings have been saved.'
+                showMessage(message)             
+             except:
+                message = 'ERROR: The custom settings could not be saved.'
+                showMessage(message)             
+                
         def doSetCurrent(self):     
              ''' Set CURRENT values in the GUI''' ##FIXME: split reading and setting into seperate methods!!!
              
@@ -348,6 +389,10 @@ class MyMainWindow(QtGui.QMainWindow):
              self.ui.radioSwappiness.setChecked(False)
              self.ui.radioDirtyBGDRatio.setChecked(False)
 
+             self.ui.radiommc0requests.setChecked(False)
+             self.ui.radiommc1requests.setChecked(False)
+             self.ui.radioMinFreekbytes.setChecked(False)
+
              ##Set Values for checkboxes
              
              if os.popen('cat /proc/sys/vm/oom_kill_allocating_task').read().strip('\n') == '1':
@@ -374,6 +419,9 @@ class MyMainWindow(QtGui.QMainWindow):
              PageCluster = os.popen('cat /proc/sys/vm/page-cluster').read().strip('\n')
              DirtyWritebackCentisecs = os.popen('cat /proc/sys/vm/dirty_writeback_centisecs').read().strip('\n')
              DirtyExpireCentisecs = os.popen('cat /proc/sys/vm/dirty_expire_centisecs').read().strip('\n')
+
+             mmc0requests = os.popen('cat /sys/block/mmcblk0/queue/nr_requests').read().strip('\n')
+             minFreekbytes = os.popen('cat /proc/sys/vm/min_free_kbytes').read().strip('\n')
              
              self.ui.lineLaptopMode.setText("%s" % LaptopMode)
              self.ui.lineDirtyRatio.setText("%s" % DirtyRatio)
@@ -383,7 +431,18 @@ class MyMainWindow(QtGui.QMainWindow):
              self.ui.linePageCluster.setText("%s" % PageCluster)
              self.ui.lineDirtyWritebackCentisecs.setText("%s" % DirtyWritebackCentisecs )
              self.ui.lineDirtyExpireCentisecs.setText("%s" % DirtyExpireCentisecs)
+
+             self.ui.linemmc0requests.setText("%s" % mmc0requests)
+             self.ui.lineMinFreekbytes.setText("%s" % minFreekbytes)
              
+             if checkMMC1() == True:
+                mmc1requests = os.popen('cat /sys/block/mmcblk1/queue/nr_requests').read().strip('\n')
+                self.ui.linemmc1requests.setText("%s" % mmc1requests)
+             else:
+                self.ui.linemmc1requests.setText("128")
+                self.ui.linemmc1requests.setEnabled(False)
+                self.ui.radiommc1requests.setEnabled(False)
+                
              message = 'The CURRENT configuration options are shown.'
              showQuickMessage(message)
 
@@ -403,6 +462,10 @@ class MyMainWindow(QtGui.QMainWindow):
              self.ui.radioSwappiness.setChecked(True)
              self.ui.radioDirtyBGDRatio.setChecked(True)
 
+             self.ui.radiommc0requests.setChecked(False)
+             self.ui.radiommc1requests.setChecked(False)
+             self.ui.radioMinFreekbytes.setChecked(False)
+             
              ##Set Values for checkboxes
              self.ui.checkBoxKillAllocatingTask.setChecked(True)
              self.ui.checkBoxTCPTimestamps.setChecked(False)
@@ -418,13 +481,17 @@ class MyMainWindow(QtGui.QMainWindow):
              self.ui.lineDirtyWritebackCentisecs.setText("0")
              self.ui.lineDirtyExpireCentisecs.setText("0")
 
+             self.ui.linemmc0requests.setText("128")
+             self.ui.linemmc1requests.setText("128")
+             self.ui.lineMinFreekbytes.setText("2039")
+
              message = 'The PROPOSED configuration options are shown.'
              showQuickMessage(message)
 
         def doSetCustom(self):      
              ''' Set CUSTOM values read from a file'''
              
-             if CheckFile(PathApp, ConfigCustom) == False:
+             if checkFile(PathApp, ConfigCustom) == False:
                 message = 'There is no custom file to be read.\
                            \nYou need to create first one..'
                 showMessage(message)
@@ -450,6 +517,10 @@ class MyMainWindow(QtGui.QMainWindow):
                 self.ui.radioDirtyRatio.setChecked(False)
                 self.ui.radioSwappiness.setChecked(False)
                 self.ui.radioDirtyBGDRatio.setChecked(False)
+
+                self.ui.radiommc0requests.setChecked(False)
+                self.ui.radiommc1requests.setChecked(False)
+                self.ui.radioMinFreekbytes.setChecked(False)
                 
                 #now set those checkboxes=1 to True 
                 if configCustom.radioSwappiness == 1:
@@ -474,25 +545,29 @@ class MyMainWindow(QtGui.QMainWindow):
                    self.ui.radioTCPTimestamps.setChecked(True)
                 if configCustom.radioTCPNoMetricsSave == 1:
                    self.ui.radioTCPNoMetricsSave.setChecked(True)                   
-                   
-                Swappiness                   = configCustom.Swappiness
-                DirtyRatio                   = configCustom.DirtyRatio
-                DirtyBGDRatio                = configCustom.DirtyBGDRatio  
-                DirtyExpireCentisecs         = configCustom.DirtyExpireCentisecs
-                DirtyWritebackCentisecs      = configCustom.DirtyWritebackCentisecs
-                PageCluster                  = configCustom.PageCluster
-                VFSCachePressure             = configCustom.VFSCachePressure
-                LaptopMode                   = configCustom.LaptopMode
-               
-                self.ui.lineSwappiness.setText("%s" % Swappiness)
-                self.ui.lineDirtyRatio.setText("%s" % DirtyRatio)
-                self.ui.lineDirtyBGDRatio.setText("%s" % DirtyBGDRatio )
-                self.ui.lineDirtyExpireCentisecs.setText("%s" % DirtyExpireCentisecs)
-                self.ui.lineDirtyWritebackCentisecs.setText("%s" % DirtyWritebackCentisecs)
-                self.ui.linePageCluster.setText("%s" % PageCluster)
-                self.ui.lineVFSCachePressure.setText("%s" % VFSCachePressure)
-                self.ui.lineLaptopMode.setText("%s" % LaptopMode)
 
+                if configCustom.radiommc0requests == 1:
+                    self.ui.radiommc0requests.setChecked(True)
+                if configCustom.radiommc1requests == 1:
+                    self.ui.radiommc1requests.setChecked(True)
+                if configCustom.radioMinFreekbytes == 1:
+                    self.ui.radioMinFreekbytes.setChecked(True)
+                   
+                if checkMMC1() == True:
+                    self.ui.linemmc1requests.setText("%s" % configCustom.mmc1requests)
+               
+                self.ui.lineSwappiness.setText("%s" % configCustom.Swappiness)
+                self.ui.lineDirtyRatio.setText("%s" % configCustom.DirtyRatio)
+                self.ui.lineDirtyBGDRatio.setText("%s" % configCustom.DirtyBGDRatio )
+                self.ui.lineDirtyExpireCentisecs.setText("%s" % configCustom.DirtyExpireCentisecs)
+                self.ui.lineDirtyWritebackCentisecs.setText("%s" % configCustom.DirtyWritebackCentisecs)
+                self.ui.linePageCluster.setText("%s" % configCustom.PageCluster)
+                self.ui.lineVFSCachePressure.setText("%s" % configCustom.VFSCachePressure)
+                self.ui.lineLaptopMode.setText("%s" % configCustom.LaptopMode)
+                
+                self.ui.linemmc0requests.setText("%s" % configCustom.mmc0requests)
+                self.ui.lineMinFreekbytes.setText("%s" % configCustom.minFreekbytes)
+                
                 self.ui.checkBoxKillAllocatingTask.setChecked(False)
                 self.ui.checkBoxTCPTimestamps.setChecked(False)
                 self.ui.checkBoxTCPNoMetricsSave.setChecked(False)
@@ -514,15 +589,18 @@ class MyMainWindow(QtGui.QMainWindow):
              showQuickMessage(message)
              
              ##Read GUI.
-             DirtyRatio = self.ui.lineDirtyRatio.text()
-             Swappiness = self.ui.lineSwappiness.text()
-             DirtyBGDRatio = self.ui.lineDirtyBGDRatio.text()  
-             PageCluster = self.ui.linePageCluster.text()
-             DirtyExpireCentisecs = self.ui.lineDirtyExpireCentisecs.text()
-             DirtyWritebackCentisecs = self.ui.lineDirtyWritebackCentisecs.text()
-             LaptopMode = self.ui.lineLaptopMode.text()
-             VFSCachePressure = self.ui.lineVFSCachePressure.text()
-                
+             DirtyRatio                 = self.ui.lineDirtyRatio.text()
+             Swappiness                 = self.ui.lineSwappiness.text()
+             DirtyBGDRatio              = self.ui.lineDirtyBGDRatio.text()  
+             PageCluster                = self.ui.linePageCluster.text()
+             DirtyExpireCentisecs       = self.ui.lineDirtyExpireCentisecs.text()
+             DirtyWritebackCentisecs    = self.ui.lineDirtyWritebackCentisecs.text()
+             LaptopMode                 = self.ui.lineLaptopMode.text()
+             VFSCachePressure           = self.ui.lineVFSCachePressure.text()
+             mmc0requests               = self.ui.linemmc0requests.text()
+             mmc1requests               = self.ui.linemmc1requests.text()
+             minFreekbytes              = self.ui.lineMinFreekbytes.text()
+               
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
                 KillAllocatingTask = '1'
              else:
@@ -560,6 +638,13 @@ class MyMainWindow(QtGui.QMainWindow):
              if self.ui.radioVFSCachePressure.isChecked() == True:
                os.system('sudo %s/updateTuning VFSCachePressure %s' % (PathApp, VFSCachePressure) )
 
+             if self.ui.radiommc0requests.isChecked() == True:
+               os.system('sudo %s/updateTuning mmc0requests %s' % (PathApp, mmc0requests) )
+             if self.ui.radiommc1requests.isChecked() == True:
+               os.system('sudo %s/updateTuning mmc1requests %s' % (PathApp, mmc1requests) )
+             if self.ui.radioMinFreekbytes.isChecked() == True:
+               os.system('sudo %s/updateTuning minFreekbytes %s' % (PathApp, minFreekbytes) )
+               
              message = 'The new values have been applied to the system.\n\nINFO:They will revert to their defaults on the next reboot.\
                         \nIf you want them to persist use the Store button.'
              showMessage(message)
@@ -571,15 +656,19 @@ class MyMainWindow(QtGui.QMainWindow):
              showQuickMessage(message)
 
              ##Read GUI.
-             DirtyRatio = self.ui.lineDirtyRatio.text()
-             Swappiness = self.ui.lineSwappiness.text()
-             DirtyBGDRatio = self.ui.lineDirtyBGDRatio.text()  
-             PageCluster = self.ui.linePageCluster.text()
-             DirtyExpireCentisecs = self.ui.lineDirtyExpireCentisecs.text()
-             DirtyWritebackCentisecs = self.ui.lineDirtyWritebackCentisecs.text()
-             LaptopMode = self.ui.lineLaptopMode.text()
-             VFSCachePressure = self.ui.lineVFSCachePressure.text()
-                
+             DirtyRatio                 = self.ui.lineDirtyRatio.text()
+             Swappiness                 = self.ui.lineSwappiness.text()
+             DirtyBGDRatio              = self.ui.lineDirtyBGDRatio.text()  
+             PageCluster                = self.ui.linePageCluster.text()
+             DirtyExpireCentisecs       = self.ui.lineDirtyExpireCentisecs.text()
+             DirtyWritebackCentisecs    = self.ui.lineDirtyWritebackCentisecs.text()
+             LaptopMode                 = self.ui.lineLaptopMode.text()
+             VFSCachePressure           = self.ui.lineVFSCachePressure.text()
+
+             mmc0requests               = self.ui.linemmc0requests.text()
+             mmc1requests               = self.ui.linemmc1requests.text()
+             minFreekbytes              = self.ui.lineMinFreekbytes.text()
+               
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
                 KillAllocatingTask = '1'
              else:
@@ -594,7 +683,7 @@ class MyMainWindow(QtGui.QMainWindow):
                 TCPNoMetricsSave = '0'
             
              ##Update of the config file.
-             if CheckFile(PathTemp, ConfigTemp) == True:
+             if checkFile(PathTemp, ConfigTemp) == True:
                 try:
                    os.remove( PathTemp + "/" + ConfigTemp )
                 except:
@@ -640,6 +729,13 @@ class MyMainWindow(QtGui.QMainWindow):
                destination.write('       echo "%s" > /proc/sys/vm/dirty_background_ratio\n' % DirtyBGDRatio) 
              if self.ui.radioVFSCachePressure.isChecked() == True:
                destination.write('       echo "%s" > /proc/sys/vm/vfs_cache_pressure\n' % VFSCachePressure) 
+             if self.ui.radiommc0requests.isChecked() == True:
+               destination.write('       echo "%s" > /sys/block/mmcblk0/queue/nr_requests\n' % mmc0requests)
+             if self.ui.radiommc1requests.isChecked() == True:
+               destination.write('       echo "%s" > /sys/block/mmcblk1/queue/nr_requests\n' % mmc1requests)
+             if self.ui.radioMinFreekbytes.isChecked() == True:
+               destination.write('       echo "%s" > /proc/sys/vm/min_free_kbytes\n' % minFreekbytes)
+
              destination.write('end script\n')
              destination.close()
              
